:desc: Trackers mantain the state of the a dialogue and can be
       featurized for machine learning algorithms right out of
       the box.

.. _tracker:

Tracker
=======

.. edit-link::
   :url: https://github.com/RasaHQ/rasa/edit/master/rasa/core/trackers.py
   :text: SUGGEST DOCSTRING EDITS

.. autoclass:: rasa.core.trackers.DialogueStateTracker
   :members:
